pub enum RecoveryShardState<PresentShard, MissingShard> {
Present(PresentShard),
MissingRecover(MissingShard),
MissingIgnore,
}Expand description
State of the shard for recovery
Variants
Present(PresentShard)
Shard is present and will be used for recovery
MissingRecover(MissingShard)
Shard is missing and needs to be recovered
MissingIgnore
Shard is missing and does not need to be recovered.
This is only allowed for parity shards, all source shards must always be present or recovered.