ShardsBitmap

Struct ShardsBitmap 

pub struct ShardsBitmap<const NUM_SHARDS: usize> { /* private fields */ }
A bit per shard, typically saying whether that shard is present.

Bit index % 64 of word index / 64 corresponds to shard index, which is the same layout reed_solomon_simd::rate::ReceivedShards uses.

Implementations

Source

impl<const NUM_SHARDS: usize> ShardsBitmap<NUM_SHARDS>

pub const fn none() -> Self

Bitmap with no shards set

pub const fn all() -> Self

Bitmap with all shards set

pub const fn get(&self, index: usize) -> bool

Whether the shard at index is set, false if index is out of bounds

pub const fn set(&mut self, index: usize)

Sets the shard at index, does nothing if index is out of bounds

pub const fn unset(&mut self, index: usize)

Unsets the shard at index, does nothing if index is out of bounds

pub const fn count(&self) -> usize

Number of shards that are set