pub struct ShardsBitmap<const NUM_SHARDS: usize> { /* private fields */ }Expand description
A bit per shard, typically saying whether that shard is present.
Bit index % 64 of word index / 64 corresponds to shard index, which is the same layout
reed_solomon_simd::rate::ReceivedShards uses.
Implementations
Sourceimpl<const NUM_SHARDS: usize> ShardsBitmap<NUM_SHARDS>
impl<const NUM_SHARDS: usize> ShardsBitmap<NUM_SHARDS>
Sourcepub const fn get(&self, index: usize) -> bool
pub const fn get(&self, index: usize) -> bool
Whether the shard at index is set, false if index is out of bounds
Sourcepub const fn set(&mut self, index: usize)
pub const fn set(&mut self, index: usize)
Sets the shard at index, does nothing if index is out of bounds